ToolBundle

Struct ToolBundle 

pub struct ToolBundle { /* private fields */ }
A collection of Tool implementations dispatched by name.

Implementations

Source

impl ToolBundle

pub fn new() -> Self

pub fn with<T: Tool + 'static>(self, tool: T) -> Self

Add a tool to this bundle, returning self for chaining.

pub fn push<T: Tool + 'static>(&mut self, tool: T)

Add a tool to this bundle in-place.

pub fn push_boxed(&mut self, tool: Box<dyn Tool>)

Add an already-boxed tool in-place.

pub fn remove(&mut self, name: &str)

Remove the tool that provides the given function name.

pub fn remove_by_names(&mut self, names: &[String])

Remove all tools whose raw_tools() contains any of the given names.

pub fn tools(&self) -> impl Iterator<Item = &dyn Tool>

Iterate over the registered tools (read-only).

pub fn len(&self) -> usize

Return the number of registered tools.

pub fn is_empty(&self) -> bool

Returns true if no tools have been registered.

pub fn clear(&mut self)

Remove all tools from this bundle.